@@ -20,17 +20,17 @@
 #'   choosing the disc radius (for classical contagion this distance is fixed by
 #'   the map resolution).
 #'
-#'   Note: to create \code{fv} objects the function copies about 20 lines of code from the \pkg{spatstat} package.
+#'   Note: to create \code{fv} objects the function copies about 20 lines of code from the \pkg{spatstat} collection of packages.
 #'
 #' @param XiH Conditional spherical contact distribution function for \eqn{\Xi}.
 #'   Typically this is an \code{fv} object but could also be a vector of values.
 #'   In applications \code{XiH} would likely be estimated from a binary map
-#'   using \code{\link[spatstat.core]{Hest}} in \pkg{spatstat}.
+#'   using \code{\link[spatstat.explore]{Hest}} in \pkg{spatstat.explore}.
 #' @param XicH Conditional spherical contact distribution for the complement of
 #'   \eqn{\Xi}. This is called the Conditional Core Probability in Hingee 2016.
 #'   Typically this is an \code{fv} object but could also be a vector of values.
 #'   In applications \code{XiH} would likely be estimated from a binary map using
-#'   \code{\link[spatstat.core]{Hest}} in \pkg{spatstat}.
+#'   \code{\link[spatstat.explore]{Hest}} in \pkg{spatstat.explore}.
 #' @param p  The coverage probability of \eqn{\Xi}. Can be estimated from binary maps using \code{\link{coverageprob}}.
 #' @param normalise Optional. If TRUE \code{contagdiscstate} normalises the
 #'   results so that all RACS return a value between 0 and 1. Default is FALSE.
@@ -77,8 +77,8 @@ contagdiscstate <- function(XiH, XicH, p, normalise=FALSE){
     returnfv <- TRUE
     unitnames <- unitname(XiH)
     fvin <- list(XiH = XiH, XicH = XicH)
-    XiHf <- as.function.fv(XiH, value = ".y", extrapolate = TRUE)
-    XicHf <- as.function.fv(XicH, value = ".y", extrapolate = TRUE)
+    XiHf <- spatstat.explore::as.function.fv(XiH, value = ".y", extrapolate = TRUE)
+    XicHf <- spatstat.explore::as.function.fv(XicH, value = ".y", extrapolate = TRUE)
     argranges <- lapply(list(XiH = XiH, XicH = XicH), argumentrange)
     ## determine finest resolution (from spatstat)
     xsteps <- sapply(fvin, argumentstep)
@@ -110,7 +110,7 @@ contagdiscstate <- function(XiH, XicH, p, normalise=FALSE){
     contag <- 1 + contag / (-2 * log(2))
   }
   if (returnfv) {
-  return(fv(data.frame(r = xvals,
+  return(spatstat.explore::fv(data.frame(r = xvals,
                        contag = contag),
             valu = "contag",
             desc = c("radius",
